@@ -5,7 +5,7 @@ pdb <- cranJuly2014
 
 \dontrun{
   pdb <- pkgAvail(
-    repos = c(CRAN = "http://mran.microsoft.com"),
+    repos = c(CRAN = getOption("minicran.mran")),
     type = "source"
   )
 }
@@ -13,19 +13,19 @@ pdb <- cranJuly2014
 dg <- makeDepGraph(tags, availPkgs = pdb  , includeBasePkgs = FALSE,
                    suggests = TRUE, enhances = TRUE)
 
-set.seed(42); 
+set.seed(42);
 plot(dg)
 
 # Move edge legend to top left
-set.seed(42); 
+set.seed(42);
 plot(dg, legendPosition = c(-1, 1))
 
 # Change font size and shape size
-set.seed(42); 
+set.seed(42);
 plot(dg, legendPosition = c(-1, 1), vertex.size = 20,  cex = 0.5)
 
 
 # Move vertex legend to top right
-set.seed(42); 
+set.seed(42);
 plot(dg, legendPosition = c(1, 1), vertex.size = 20,  cex = 0.5)
 
